==> ejc-assistrmat-impl-3.0.0-20220915.064809-204-sources.jar: com/ejianc/business/outrmat/contract/service/impl/OutRmatContractSignatureServiceImpl.java <==
package com.ejianc.business.outrmat.contract.service.impl;

import com.ejianc.business.common.CommonConstant;
import com.ejianc.business.outrmat.contract.bean.OutRmatContractChangeEntity;
import com.ejianc.business.outrmat.contract.bean.OutRmatContractEntity;
import com.ejianc.business.outrmat.contract.enums.PerformanceStatusEnum;
import com.ejianc.business.outrmat.contract.enums.SignatureStatusEnum;
import com.ejianc.business.outrmat.contract.service.IOutRmatContractChangeService;
import com.ejianc.business.outrmat.contract.service.IOutRmatContractFileService;
import com.ejianc.business.outrmat.contract.service.IOutRmatContractService;
import com.ejianc.business.outrmat.contract.service.IOutRmatContractSignatureService;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service("outRmatContractSignatureService")
public class OutRmatContractSignatureServiceImpl implements IOutRmatContractSignatureService {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IOutRmatContractService contractService;

    @Autowired
    private IOutRmatContractChangeService changeService;

    @Autowired
    private IOutRmatContractFileService contractFileService;

    /**
     * 签章流程
     * 单据签章状态修改逻辑
     * 1.主合同若签章状态为已签章，则修改主合同签章状态和合同状态以及生效时间，否则只修改签章状态
     * 2.变更合同
     * 若签章状态为已签章则将变更信息回写主合同，生成变更记录，改变变更合同签章状态
     * 否则改变变更合同签章状态，修改主合同的变更合同签章状态
     *
     * @param id
     * @param signatureStatus
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> changeStatus(Long id, Integer signatureStatus, String refCode) {
        logger.info("进入签章状态修改流程------------->");
        // signatureStatus - 1 是因为分包的签章状态是1234，签章服务传递的参数也是固定的1234，但这边是0123，需要-1
//        signatureStatus = signatureStatus - 1;
        if (CommonConstant.OUT_RMAT_CONTRACT_REFCODE.equals(refCode)) {//主合同
            OutRmatContractEntity contractEntity = contractService.selectById(id);
            if (contractEntity != null) {
                if (SignatureStatusEnum.已签章.getCode().equals(signatureStatus)) {
                    contractEntity.setSignatureStatus(SignatureStatusEnum.已签章.getCode());
                    contractEntity.setPerformanceStatus(PerformanceStatusEnum.履约中.getCode());
//                    contractEntity.setEffectiveDate(new Date());
                }
                else {
                    contractEntity.setSignatureStatus(signatureStatus);
                }
                contractService.saveOrUpdate(contractEntity, false);

                if (SignatureStatusEnum.已签章.getCode().equals(signatureStatus)) {
                    //更新合同的 签章文件id - signFieldId
                    contractFileService.getSignedFileInfo(id, "contract");
                }
                logger.info("主合同签章状态已修改---------------->");
            }
            else {
                return CommonResponse.error("找不到合同，请检查合同主键！");
            }
        }
        else if (CommonConstant.OUT_RMAT_CONTRACT_REFCODE_CHANGE.equals(refCode)) {//变更合同
            OutRmatContractChangeEntity changeEntity = changeService.selectById(id);
            if (changeEntity != null) {
                if (SignatureStatusEnum.已签章.getCode().equals(signatureStatus)) {
                    return changeService.effectiveSaveWriteContract(id, changeEntity.getBillCode(), false);
                }
                else {
                    changeEntity.setSignatureStatus(signatureStatus);
                    changeService.saveOrUpdate(changeEntity);
                    logger.info("变更合同签章状态已修改---------------->");
                    //回写主合同（变更合同签章状态，主合同变更状态）
//                    LambdaUpdateWrapper<OutRmatContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
//                    updateWrapper.eq(OutRmatContractEntity::getId, changeEntity.getContractId());
//                    updateWrapper.set(OutRmatContractEntity::getChangeContractSignatureStatus, changeEntity.getSignatureStatus());
//                    contractService.update(contractService.selectById(changeEntity.getContractId()), updateWrapper, false);
                    OutRmatContractEntity outRmatContractEntity = contractService.selectById(changeEntity.getContractId());
                    outRmatContractEntity.setChangeContractSignatureStatus(changeEntity.getSignatureStatus().toString());
                    contractService.saveOrUpdate(outRmatContractEntity);

                    logger.info("签章状态为已签章，回写主合同签章状态---------------->");
                }
            }
            else {
                return CommonResponse.error("找不到合同，请检查合同主键！");
            }
        }
        else {
            return CommonResponse.error("请检查refCode值是否正确！");
        }
        return CommonResponse.success("签章状态修改成功！");
    }
}

==> ejc-assistrmat-impl-3.0.0-20221010.100411-255-sources.jar: com/ejianc/business/outrmat/contract/service/impl/OutRmatContractSignatureServiceImpl.java <==
package com.ejianc.business.outrmat.contract.service.impl;

import com.ejianc.business.common.CommonConstant;
import com.ejianc.business.contractbase.filing.enums.FilingStatusEnum;
import com.ejianc.business.outrmat.contract.bean.OutRmatContractChangeEntity;
import com.ejianc.business.outrmat.contract.bean.OutRmatContractEntity;
import com.ejianc.business.outrmat.contract.enums.PerformanceStatusEnum;
import com.ejianc.business.outrmat.contract.enums.SignatureStatusEnum;
import com.ejianc.business.outrmat.contract.service.IOutRmatContractChangeService;
import com.ejianc.business.outrmat.contract.service.IOutRmatContractFileService;
import com.ejianc.business.outrmat.contract.service.IOutRmatContractService;
import com.ejianc.business.outrmat.contract.service.IOutRmatContractSignatureService;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service("outRmatContractSignatureService")
public class OutRmatContractSignatureServiceImpl implements IOutRmatContractSignatureService {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IOutRmatContractService contractService;

    @Autowired
    private IOutRmatContractChangeService changeService;

    @Autowired
    private IOutRmatContractFileService contractFileService;

    /**
     * 签章流程
     * 单据签章状态修改逻辑
     * 1.主合同若签章状态为已签章，则修改主合同签章状态和合同状态以及生效时间，否则只修改签章状态
     * 2.变更合同
     * 若签章状态为已签章则将变更信息回写主合同，生成变更记录，改变变更合同签章状态
     * 否则改变变更合同签章状态，修改主合同的变更合同签章状态
     *
     * @param id
     * @param signatureStatus
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> changeStatus(Long id, Integer signatureStatus, String refCode) {
        logger.info("进入签章状态修改流程------------->");
        // signatureStatus - 1 是因为分包的签章状态是1234，签章服务传递的参数也是固定的1234，但这边是0123，需要-1
//        signatureStatus = signatureStatus - 1;
        if (CommonConstant.OUT_RMAT_CONTRACT_REFCODE.equals(refCode)) {//主合同
            OutRmatContractEntity contractEntity = contractService.selectById(id);
            if (contractEntity != null) {
                if (SignatureStatusEnum.已签章.getCode().equals(signatureStatus)) {
                    contractEntity.setSignatureStatus(SignatureStatusEnum.已签章.getCode());
                    contractEntity.setPerformanceStatus(PerformanceStatusEnum.履约中.getCode());
                    contractEntity.setFilingStatus(FilingStatusEnum.已归档.getTypeCode());
                    contractEntity.setFilingRef(0);
//                    contractEntity.setEffectiveDate(new Date());
                }
                else {
                    contractEntity.setSignatureStatus(signatureStatus);
                }
                contractService.saveOrUpdate(contractEntity, false);

                if (SignatureStatusEnum.已签章.getCode().equals(signatureStatus)) {
                    //更新合同的 签章文件id - signFieldId
                    contractFileService.getSignedFileInfo(id, "contract");
                }
                logger.info("主合同签章状态已修改---------------->");
            }
            else {
                return CommonResponse.error("找不到合同，请检查合同主键！");
            }
        }
        else if (CommonConstant.OUT_RMAT_CONTRACT_REFCODE_CHANGE.equals(refCode)) {//变更合同
            OutRmatContractChangeEntity changeEntity = changeService.selectById(id);
            if (changeEntity != null) {
                if (SignatureStatusEnum.已签章.getCode().equals(signatureStatus)) {
                    return changeService.effectiveSaveWriteContract(id, changeEntity.getBillCode(), false, true);
                }
                else {
                    changeEntity.setSignatureStatus(signatureStatus);
                    changeService.saveOrUpdate(changeEntity);
                    logger.info("变更合同签章状态已修改---------------->");
                    //回写主合同（变更合同签章状态，主合同变更状态）
//                    LambdaUpdateWrapper<OutRmatContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
//                    updateWrapper.eq(OutRmatContractEntity::getId, changeEntity.getContractId());
//                    updateWrapper.set(OutRmatContractEntity::getChangeContractSignatureStatus, changeEntity.getSignatureStatus());
//                    contractService.update(contractService.selectById(changeEntity.getContractId()), updateWrapper, false);
                    OutRmatContractEntity outRmatContractEntity = contractService.selectById(changeEntity.getContractId());
                    outRmatContractEntity.setChangeContractSignatureStatus(changeEntity.getSignatureStatus().toString());
                    contractService.saveOrUpdate(outRmatContractEntity);

                    logger.info("签章状态为已签章，回写主合同签章状态---------------->");
                }
            }
            else {
                return CommonResponse.error("找不到合同，请检查合同主键！");
            }
        }
        else {
            return CommonResponse.error("请检查refCode值是否正确！");
        }
        return CommonResponse.success("签章状态修改成功！");
    }
}
